Enum AnimationProgress
#[repr(u8)]pub enum AnimationProgress {
None = 0,
Minimum = 3,
Cancel = 4,
Reset = 5,
NoData = 6,
Unknown(u8),
}Expand description
Animation progress.
Variants
None = 0
None.
Minimum = 3
Stopped animation with reaching minimum of first trigger point or tooltip time.
Cancel = 4
Stopped animation without reaching minimum of first trigger point or tooltip time.
Reset = 5
Animation completed fully.
NoData = 6
Same as Minimum but on 0/uncertain expected duration.
Unknown(u8)
Unknown or invalid.